document.addEventListener('DOMContentLoaded', () => {
    const animateElements = document.querySelectorAll('.ss-element');

    const observerOptions = {
        root: null,
        rootMargin: '0px',
        threshold: 0.1
    };

    const animationObserver = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            const element = entry.target;
            const delay = parseInt(element.getAttribute('data-delay'), 10) || 100;
            const animationType = element.getAttribute('data-ss');

            if (entry.isIntersecting) {
                // Only add the animation if it's not already animated
                if (!element.classList.contains('animate__animated')) {
                    setTimeout(() => {
                        if (animationType) {
                            element.classList.add('animate__animated', `animate__${animationType}`);
                        }
                    }, delay);
                }
            } else {
                // Optionally, keep the animation classes for a smooth exit
                // To allow for potential re-animation, you might not want to remove classes here
                // Uncomment the next line if you want to remove animation classes on exit
                 element.classList.remove('animate__animated', `animate__${animationType}`);
            }
        });
    }, observerOptions);

    // Fallback for browsers that don't support Intersection Observer
    if (!('IntersectionObserver' in window)) {
        animateElements.forEach(element => {
            const animationType = element.getAttribute('data-ss');
            if (animationType) {
                element.classList.add('animate__animated', `animate__${animationType}`);
            }
        });
    } else {
        animateElements.forEach(element => {
            animationObserver.observe(element);
        });
    }
});
